@@ -5,7 +5,8 @@ function (x, type=c("spec", "pred", "diag"), ...)
     stop("Not a 'car' object\n")
     type <- match.arg(type)
     if(type=="spec")
-    plot.spec(x, ...)
+    plot(x, ...)
+    #plot.spec(x, ...)
     if(type=="pred")
     plot.predict.car(x, ...)
     if(type=="diag")
